[telepathy-gabble/master] Don't repeat RequestStreams for the wrong handle.

Will Thompson will.thompson at collabora.co.uk
Tue May 12 03:12:02 PDT 2009


This papered over a bug where capabilities-discovered was emitted for
the wrong handle, and now is harmless but silly.
---
 src/media-channel.c |    6 +++++-
 1 files changed, 5 insertions(+), 1 deletions(-)

diff --git a/src/media-channel.c b/src/media-channel.c
index 0e98281..973744e 100644
--- a/src/media-channel.c
+++ b/src/media-channel.c
@@ -1769,7 +1769,11 @@ capabilities_discovered_cb (GabblePresenceCache *cache,
                             TpHandle handle,
                             struct _delayed_request_streams_ctx *ctx)
 {
-  /* If there are more cache caps pending, wait for them. */
+  /* If this isn't the contact we're waiting for, ignore the signal. */
+  if (ctx->contact_handle != handle)
+    return;
+
+  /* If there are more cache caps pending for this contact, wait for them. */
   if (gabble_presence_cache_caps_pending (cache, handle))
     return;
 
-- 
1.5.6.5



More information about the telepathy-commits mailing list